<?php

class Teqpay
{
    public $urls = [
        'test' => 'https://merchant-test.teqpay.com/api/teqpay',
        'prod' => 'https://merchant.teqpay.com/api/teqpay'
    ];
    public $debug = false;
    public $env;

    public function __construct($api_key, $secret_key, $env, $debug = 0 ){
        $this->env = $env;
        $this->debug = $debug;
        $this->api_key = $api_key;
        $this->secret_key = $secret_key;
        $this->url = $this->urls[ $env ];
    }

    //paymentcheck

    public function checkPaymentStatus( $referenceNo ){
        $data = [ "ConversationId" => $referenceNo ];
        $call = $this->makeRequest($this->url . "/paymentcheck", $data);
        
        /*
            {   
                "Details": {
                    "CustomerName": "DENEMEAD DENEMESOYAD",
                    "CitizenNo": "11111111111",
                    "Price": 21.92,
                    "TotalPrice": 21.92,
                    "Discount": "0,00 TL",
                    "OrderID": 6679,
                    "ConversationId": "PRO02081T21458",
                    "DateTime": "02.08.2021 17:03:25",
                    "PaymentType": "SANALPOS",
                    "PaymentCompany": "MOKA",
                    "OrderStatus": "Ödeme Başarılı"
                },  
                "Result": true,
                "ResultCode": 10000,
                "ResultMessage": "Başarıyla tamamlandı."  
            }
        */

        if(!$call)
            die("<div class='error warning alert'>Veri Okunamadı</div>");

        if( (!isset($call->ResultCode) OR $call->ResultCode != 10000) OR (!isset($call->Details->OrderStatusCode) OR $call->Details->OrderStatusCode != 1) ){
            $text = $call->Details->OrderStatus ? $call->Details->OrderStatus : $call->ResultMessage;
            return [
                "status" => "fail",
                "message" => $text,
                "data" => $call,
            ];
        }else{
            return [
                "status" => "success",
                "message" => "",
                "data" => $call,
            ];
        }
    }

    public function getInstallmentInfo( $card_no, $price ){
        $data = [ "cardNo" => $card_no, "price" => $price, "language" => "" ];
        $call = (array) $this->makeRequest($this->url . "/installmentinfo", $data);

        if(!$call)
            die("<div class='error warning alert'>Veri Okunamadı</div>");

        if($call["ResultCode"] != 10000){
            $text = $call['ResultMessage'];
            return [
                "status" => "fail",
                "message" => $text
            ];
        }else{
            return [
                "status" => "success",
                "message" => "",
                "data" => $call['Details']
            ];
        }
    }

    public function makeCommonpaymentTransaction(  $transaction ){
        $call =  $this->makeRequest($this->url . "/paywithcommonpage", $transaction);


        
        if(!$call)
            die("<div class='error warning alert'>Veri Okunamadı</div>");

        if( $call->ResultCode != 10000){
            $text = $call->ResultMessage;
            return [
                "status" => "fail",
                "message" => $text
            ];
        }else{
            return [
                "status" => "success",
                "message" => "",
                "data" => $call,
                "redirect_url" => $call->PaymentData->PaymentUrl
            ];
        }
    }


    public function makeTransaction(  $transaction ){
        $call =  $this->makeRequest($this->url . "/payment", $transaction);
        //dump($call);exit;
        if(!$call)
            die("<div class='error warning alert'>Veri Okunamadı</div>");

        if(!isset($call->ResultCode) OR $call->ResultCode != 10000){
            $text = isset($call->Message) ? $call->Message : '';
            $text .= isset($call->ResultMessage) ? $call->ResultMessage : '';
            return [
                "status" => "fail",
                "message" => $text
            ];
        }else{
            return [
                "status" => "success",
                "message" => "",
                "data" => $call,
                "redirect_url" => $call->PaymentData->PaymentUrl
            ];
        }
    }

    public function makeRequest($endpoint, $data, $method = 'POST')
    {
        $curl_header = [
            "Content-Type: application/json",
            "ApiKey: " . $this->api_key,
            "SecretKey: " . $this->secret_key,
        ];
        $url = $endpoint;

        if ($method == 'GET')
            $url .= "?" . http_build_query($data);

        $ch = curl_init($url);

        if ($method == 'POST')
            curl_setopt($ch, CURLOPT_POST, 1);

         curl_setopt($ch, CURLOPT_HTTPHEADER, $curl_header);

        if ($method == 'POST')
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));

        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_TIMEOUT, 90);
        $output1 = curl_exec($ch);
        $output2 = json_decode($output1);
        curl_close($ch);

        if ($this->debug) {
            dump([
                "endpoint" => $endpoint,
                "data" => $data,
                "header" => $curl_header,
                "output1" => $output1,
                "output2" => $output2,
            ]);
            //exit;
        }

        if (!isJson($output1))
            return false;

        return $output2;
    }
}



class TeqpayTransaction{
    public $cartId;
    public  $apiKey;
    public  $email;
    public  $amount;
    public  $currency;
    public  $returnUrl;
    public  $referenceNo;
    public  $showInstallmentList;
    public  $language;
    public  $billingFirstName;
    public  $billingLastName;
    public  $billingCompany;
    public  $billingAddress1;
    public  $billingAddress2;
    public  $billingCity;
    public  $billingPostcode;
    public  $billingCountry;
    public  $billingPhone;
    public  $basketItems;
    public  $storeCard;
    public  $sessionId;
    public  $passwordHash;
    public  $userCreated;
    public $shippingFirstName;
    public $shippingLastName;
    public $shippingAddress1;
    public $shippingCity;
    public $shippingPostcode;
    public $shippingCountry;
    public $shippingPhone;
    public $pan;
    public $holder_name;
    public $expiration_month;
    public $expiration_year;
    public $cvv;
    public $installment;
}

if (!function_exists('dump')) {
    function dump($data)
    {
        echo '<pre>' . var_export($data, true) . '</pre>';
        /* highlight_string("<?php\n\$data =\n" . var_export($data, true) . ";\n?>"); */
    }
}

if (!function_exists('isJson')) {
    function isJson($string)
    {
        json_decode($string);
        return (json_last_error() == JSON_ERROR_NONE);
    }
}