<?php

/**
 * @since 1.5.0
 */
require_once dirname(__FILE__) . '/../../classes/Teqpay.php';
require_once dirname(__FILE__) . '/../../classes/Transaction.php';

class payment_teqpaypaymentModuleFrontController extends ModuleFrontController
{
    public function initContent()
    {
        parent::initContent();
        $currency = new Currency($this->context->cart->id_currency);
        $cart = $this->context->cart;

        if (!$this->module->checkCurrency($cart))
            Tools::redirect('index.php?controller=order');

        if (!empty($_SERVER['HTTP_CLIENT_IP'])) {
    $ip = $_SERVER['HTTP_CLIENT_IP'];
} elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
    $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
} else {
    $ip = $_SERVER['REMOTE_ADDR'];
}

        $order_info                     = $this->context->cart;
        $customer                       = new Customer(intval($order_info->id_customer));
        $address                        = new Address(intval($order_info->id_address_invoice));
        $shipping_address               = new Address(intval($order_info->id_address_delivery));
        $country                        = new Country(intval($address->id_country));
        $shipping_country               = new Country(intval($address->id_country));
        $country_name                   = $country->name[$this->context->language->id];
        $shippingcountry_name           = $shipping_country->name[$this->context->language->id]; 
        $cart_products                  = $order_info->getProducts();
        $order_reference                = "PS_SIP_" . $order_info->id . "_" . date('dmY') . "_" . rand(100, 999);
        $items                          = [];
        foreach ($cart_products as $product) {
            //dump($product);exit;
            $itemAmount = floatval(number_format($product["total_wt"], 2, '.', ''));
            $producti = array(
                "itemType"          => "Products",
                "merchantItemId"    => ($product["reference"] != "" ? $product["reference"] : $product["id_product"]),
                "itemName"          => substr($product["name"], 0, 60),  //"name"=> substr($product["name"] , 0 , 60),
                "itemCategory"      => $product["category"],
                "itemQuantity"      => $product["quantity"],
                "itemPrice"         => $itemAmount
            );
            $object = json_decode(json_encode($producti), FALSE);
            $items[] = $object;
        }
        //$items = ["basketItems" => $items];
        //dump($address);exit;
        $teqpay = new Teqpay(
            Configuration::get('payment_teqpay_apiKey'),
            Configuration::get('payment_teqpay_secretKey'),
            Configuration::get('payment_teqpay_env'),
            Configuration::get('payment_teqpay_debug')
        );


        $transactionData = [
                'customerName' => $customer->firstname . " " . $customer->lastname,
                'customerIpAddress' => $ip == '::1' ? '127.0.0.1' : $ip,
                'customerCitizenNo' => '12345678900',
                'customerEmail' => (string) $customer->email,
                'customerPhone' => $address->phone != '' ? $address->phone : "1234567890" ,
                'price' => (float) number_format($order_info->getOrderTotal(true), 2, '.', ''),
                "currency" => strtoupper($currency->iso_code),
                'conversationId' => (string) $order_reference,
                'callbackUrl' => $this->context->link->getModuleLink('payment_teqpay', 'validation', array(), true),
                'isPreAuth' => 0,
                'language' => strtoupper($this->context->language->iso_code),
                'paymentMethodId' => "1",
                'products' => $items,
                'billing' => [
                  'billingName' => $customer->firstname . " " . $customer->lastname,
                  'billingCity' => $address->city,
                  'billingCountry' => $country_name,
                  'billingAddress' => $address->address1,
                ],
                'shipping' => [
                  'shippingContactName' => $customer->firstname . " " . $customer->lastname,
                  'shippingCity' => $shipping_address->city,
                  'shippingCountry' => $shippingcountry_name,
                  'shippingAddress' => $shipping_address->address1,
                ],
            ];

        if( Tools::getValue('payment_method') == 'direct3d' ){
            unset($transactionData['isPreAuth']);
            $transactionData['paymentMethodId'] = "1";
            $transactionData['cardData'] = [
                    'cardNo' => Tools::getValue('pan'),
                    'cardHolderName' => Tools::getValue('cardOwner'),
                    'expDate' => Tools::getValue('expiryMonth') . "/" . substr (Tools::getValue('expiryYear'), -2) ,
                    'cvv' => Tools::getValue('cvv'),
                    'installment' => (int) Tools::getValue('installmentCount'),
                    'isPreAuth' => "false",
                ];
                $transactionData['moneyTransferData'] = [
                    'ibanNo' => null,
                    'moneyTransferCode' => null
                ];

                $runTransaction = $teqpay->makeTransaction( $transactionData );
        }else{
            $transactionData['paymentMethodId'] = null;
            $transactionData['installments'] = [];
            $runTransaction = $teqpay->makeCommonpaymentTransaction( $transactionData );
        }    

        if( $runTransaction["status"] == "success" ){

            //save current state
            $call = $runTransaction["data"];
            $object = new Transaction();
            $object->order_id =$order_info->id;
            $object->status = "Redirected 3D Secure";
            $object->amount = $call->PaymentData->Price;
            $object->currency = "";
            $object->type = "";
            $object->reference = "";
            $object->operation = "";
            $object->transactionId = $call->PaymentData->ConversationId;
            $object->message = $call->PaymentData->TransactionDate;
            $object->code = "";
            $object->purchase_url = $call->PaymentData->PaymentUrl;
            $object->save();
            sleep(1);
            Tools::redirect( $call->PaymentData->PaymentUrl );
        }else{
            $this->context->controller->errors[] = $runTransaction["message"];
            $this->context->controller->redirectWithNotifications(
                'order'
            );
        }
    }
}
