<?php

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}

class payment_teqpay extends PaymentModule
{
    protected $_html = '';
    protected $_postErrors = array();

    public $details;
    public $owner;
    public $address;
    public $extra_mail_vars;

    public function __construct()
    {
        $this->name = 'payment_teqpay';
        $this->tab = 'payments_gateways';
        $this->version = '1.0.0';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => '1.7.99.99');
        $this->author = 'magento-tr';
        $this->controllers = array('validation', 'payment', 'ajax');
        $this->is_eu_compatible = 1;

        $this->currencies = true;
        $this->currencies_mode = 'checkbox';

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('TeqPay Payment Gateway');
        $this->description = $this->l('Accept Credit Card Payments via TeqPay Payment Gateway');

        if (!count(Currency::checkPaymentCurrencies($this->id))) {
            $this->warning = $this->l('No currency has been set for this module.');
        }
    }

    public function _isUsingNewTranslationSystem(){
        return false;
    }

    public function hookDisplayHeader()
    {
        if ($this->context->controller->php_self == 'order') {
            Media::addJsDef(["teqpay_ajax_url" => $this->context->link->getModuleLink($this->name, 'ajax', [])]);
            $this->context->controller->addJS($this->_path . 'assets/js/custom.js');
            $this->context->controller->addCss($this->_path . 'views/css/payment_teqpay.css', 'all');
        }
    }

    protected function _postProcess()
    {
        if (Tools::isSubmit('btnSubmit')) {
            Configuration::updateValue('payment_teqpay_apiKey', Tools::getValue('payment_teqpay_apiKey'));
            Configuration::updateValue('payment_teqpay_secretKey', Tools::getValue('payment_teqpay_secretKey'));
            Configuration::updateValue('payment_teqpay_showPaybycard', Tools::getValue('payment_teqpay_showPaybycard'));
            Configuration::updateValue('payment_teqpay_env', Tools::getValue('payment_teqpay_env'));
            Configuration::updateValue('payment_teqpay_debug', Tools::getValue('payment_teqpay_debug'));
        }
        $this->_html .= $this->displayConfirmation($this->l('Settings updated'));
    }
    
    public function getContent()
    {
        if (Tools::isSubmit('btnSubmit')) {
            //$this->_postValidation();
            if (!count($this->_postErrors))
                $this->_postProcess();
            else
                foreach ($this->_postErrors as $err)
                    $this->_html .= $this->displayError($err);
        } else
            $this->_html .= '<br />';

        $this->_html .= $this->_displayInfo();
        $this->_html .= $this->renderForm();

        return $this->_html;
    }

    protected function _displayInfo()
    {
        //return $this->display(__FILE__, 'infos.tpl');
        return "";
    }

    public function renderForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Teqpay Payment Gateway Parameters'),
                    'icon' => 'icon-envelope'
                ),
                'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('API Key'),
                        'name' => 'payment_teqpay_apiKey',
                        'required' => true
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Secret Key'),
                        'name' => 'payment_teqpay_secretKey',
                        'required' => true
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Show Credit Card Payment Method'),
                        'name' => 'payment_teqpay_showPaybycard',
                        'required' => true,
                        'options' => array(
                            'query' => array(
                                array(
                                    'id_option' => 1,
                                    'name' => 'Enable'
                                ),
                                array(
                                    'id_option' => 0,
                                    'name' => 'Disable'
                                ),
                            ),
                            'id' => 'id_option',
                            'name' => 'name'
                        ),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Test / Live Mode'),
                        'name' => 'payment_teqpay_env',
                        'required' => true,
                        'options' => array(
                            'query' => array(
                                array(
                                    'id_option' => 'test',
                                    'name' => 'Test'
                                ),
                                array(
                                    'id_option' => 'prod',
                                    'name' => 'Live'
                                ),
                            ),
                            'id' => 'id_option',
                            'name' => 'name'
                        ),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Debug Mode'),
                        'name' => 'payment_teqpay_debug',
                        'required' => true,
                        'options' => array(
                            'query' => array(
                                array(
                                    'id_option' => 1,
                                    'name' => 'Enable'
                                ),
                                array(
                                    'id_option' => 0,
                                    'name' => 'Disable'
                                ),
                            ),
                            'id' => 'id_option',
                            'name' => 'name'
                        ),
                    )
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $lang = new Language((int) Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $this->fields_form = array();
        $helper->id = (int) Tools::getValue('id_carrier');
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'btnSubmit';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false) . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );

        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {
        return array(
            'payment_teqpay_apiKey' => Tools::getValue('payment_teqpay_apiKey', Configuration::get('payment_teqpay_apiKey')),
            'payment_teqpay_secretKey' => Tools::getValue('payment_teqpay_secretKey', Configuration::get('payment_teqpay_secretKey')),
            'payment_teqpay_showPaybycard' => Tools::getValue('payment_teqpay_showPaybycard', Configuration::get('payment_teqpay_showPaybycard')),
            'payment_teqpay_env' => Tools::getValue('payment_teqpay_env', Configuration::get('payment_teqpay_env')),
            'payment_teqpay_debug' => Tools::getValue('payment_teqpay_debug', Configuration::get('payment_teqpay_debug')),
        );
    }

    public function install()
    {
        require_once dirname(__FILE__) . "/sqls.php";
        foreach ($install_sqls as $install_sql){
            $install_sql = str_replace("`ps_", "`" . _DB_PREFIX_, $install_sql);
            try {
                DB::getInstance()->execute($install_sql);
            }catch (exception $e){
                $this->_errors[] = get_class($e).': '.$e->getMessage();
                //$this->uninstall();
                return false;
            }
        }


        if (
            !parent::install()
            || !$this->registerHook('paymentOptions')
            || !$this->registerHook('displayHeader')
            //|| !$this->registerHook('paymentReturn')
            //|| !$this->registerHook('footer')
        ) {
            return false;
        }
        return true;
    }

    public function hookPaymentOptions($params)
    {
        if (!$this->active) {
            return;
        }

        if (!$this->checkCurrency($params['cart'])) {
            return;
        }

        $payment_options = [
            $this->getTeqpayPaymentOption()
        ];

        if( Configuration::get('payment_teqpay_showPaybycard') )
            $payment_options[] = $this->getPaymentOption();

        return $payment_options;
    }

    public function getTeqpayPaymentOption(){
        $returnUrl = $this->context->link->getModuleLink($this->name, 'payment', array(), true);
        $iframeOption = new PaymentOption();
        $iframeOption->setCallToActionText($this->l('TeqPay İle Öde'))
                     ->setAction($returnUrl)
                     ->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/payment.jpg'));
         return $iframeOption;
    }

    public function getPaymentOption()
    {
        $option = new PaymentOption();
            $option->setCallToActionText($this->l('Pay With Credit Card'))
                ->setForm($this->generateForm())
                ->setLogo(Media::getMediaPath(_PS_MODULE_DIR_ . $this->name . '/payment.jpg'));
        return $option;
    }

    protected function generateForm()
    {
        $cart           = $this->context->cart;
        $total          = $cart->getOrderTotal(true, Cart::BOTH);
        $months         = [];

        for ($i = 1; $i <= 12; $i++) {
            $months[] = sprintf("%02d", $i);
        }

        $years = [];
        for ($i = 0; $i <= 10; $i++) {
            $years[] = date('Y', strtotime('+' . $i . ' years'));
        }

        $this->context->smarty->assign([
            'total' => $total,
            'showPaybycard' => Configuration::get('payment_teqpay_showPaybycard'),
            'action' => $this->context->link->getModuleLink($this->name, 'payment', array(), true),
            'months' => $months,
            'years' => $years,
            'tek_cekim' => "1 x " . number_format( $total , 2) . ", Toplam : " . number_format( $total , 2),
        ]);

        return $this->context->smarty->fetch('module:payment_teqpay/views/templates/front/payment_form.tpl');
    }

    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }
}
